@@ -1,9 +1,6 @@
 #![deny(warnings)]
-use sauron::{
-    html::{attributes::*, *},
-    mt_dom::patch::*,
-    *,
-};
+use crate::mt_dom::TreePath;
+use sauron::prelude::*;
 
 use test_fixtures::simple_program;
 use wasm_bindgen_test::*;
@@ -112,19 +109,17 @@ fn test1() {
     assert_eq!(
         patch,
         vec![
-            ChangeText::new(
-                &Text::new("1"),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 1, 0, 0, 1, 0, 0,]),
-                &Text::new("0")
-            )
-            .into(),
-            ChangeText::new(
-                &Text::new("2"),
+                &leaf::text("1"),
+                &leaf::text("0")
+            ),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 1, 0, 0, 2, 0, 0,]),
-                &Text::new("3")
-            )
-            .into(),
-            InsertNode::new(
+                &leaf::text("2"),
+                &leaf::text("3")
+            ),
+            Patch::insert_node(
                 Some(&"div"),
                 TreePath::new(vec![0, 1, 0, 0, 2,]),
                 &div(
@@ -145,9 +140,8 @@ fn test1() {
                         ),
                     ]
                 ),
-            )
-            .into(),
-            InsertNode::new(
+            ),
+            Patch::insert_node(
                 Some(&"div"),
                 TreePath::new(vec![0, 1, 0, 0, 2,]),
                 &div(
@@ -163,16 +157,16 @@ fn test1() {
                         ),
                     ]
                 )
-            )
-            .into(),
-            RemoveNode::new(Some(&"div"), TreePath::new(vec![0, 1, 0, 0, 0,]),)
-                .into(),
-            ChangeText::new(
-                &Text::new("line: 0, column: 0"),
+            ),
+            Patch::remove_node(
+                Some(&"div"),
+                TreePath::new(vec![0, 1, 0, 0, 0,]),
+            ),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 1, 0, 1, 0,]),
-                &Text::new("line: 1, column: 0")
-            )
-            .into(),
+                &leaf::text("line: 0, column: 0"),
+                &leaf::text("line: 1, column: 0")
+            ),
         ]
     );
 
